@@ -149,13 +149,12 @@ class HC(object) :
                         int(np.floor(gamma * self._N + 0.5)))        
         return self._calculateHC(imin, imax)
 
-    def get_param(self) :
-        imin_star = np.argmax(self._pvals > (1-self._EPS)/ self._N)
-        imin_jim = 
+    def get_state(self) :
         return {'pvals' : self._pvals, 
                 'u' : self._uu,
                 'z' : self._zz,
-                'imin_star' : imin_star
+                'imin_star' : self._imin_star,
+                'imin_jin' : self._imin_jin,
                 }
 
 
